==> klamav_0.32.orig.tar.gz: klamav-0.32/src/configdialog.h <==
/***************************************************************************
begin                : 2004/02/07
copyright            : (C) Mark Kretschmann
email                : markey@web.de
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KLAMAVCONFIGDIALOG_H
#define KLAMAVCONFIGDIALOG_H


#include <qmap.h>
#include <qvaluelist.h>

#include <kconfigdialog.h>

class QComboBox;
class QGroupBox;
class QVBox;


class KlamavConfigDialog : public KConfigDialog
{
    Q_OBJECT

    public:
        KlamavConfigDialog( QWidget *parent, const char* name, KConfigSkeleton *config );
        ~KlamavConfigDialog();

        void addPage( QWidget *page, const QString &itemName, const QString &pixmapName,
                      const QString &header=QString::null, bool manage=true);

        void showPage( const QCString& page );

    protected slots:
        void updateSettings();
        void updateWidgets();
        void updateWidgetsDefault();

    private slots:
        void aboutEngine();
    protected:
        bool hasChanged();
        bool isDefault();

    private:
        void soundSystemChanged();

        QComboBox* m_soundSystem;
        amaroK::PluginConfig *m_engineConfig;
        QGroupBox            *m_engineConfigFrame;
        class Options1       *m_opt1;
        class Options2       *m_opt2;
        class Options4       *m_opt4;
        class Options7       *m_opt7;

        QValueList<QWidget*> m_pageList;
        QMap<QString, QString> m_pluginName;
        QMap<QString, QString> m_pluginKlamavName;
};


#endif // KLAMAVCONFIGDIALOG_H

==> klamav_0.46.orig.tar.gz: klamav-0.46/src/configdialog.h <==
/***************************************************************************
begin                : 2004/02/07
copyright            : (C) Mark Kretschmann
email                : markey@web.de
***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef KLAMAVCONFIGDIALOG_H
#define KLAMAVCONFIGDIALOG_H


#include <qmap.h>
#include <qvaluelist.h>

#include <kconfigdialog.h>

class QComboBox;
class QGroupBox;
class QVBox;


class KlamavConfigDialog : public KConfigDialog
{
    Q_OBJECT

    public:
        KlamavConfigDialog( QWidget *parent, const char* name, KConfigSkeleton *config );
        ~KlamavConfigDialog();

        void addPage( QWidget *page, const QString &itemName, const QString &pixmapName,
                      const QString &header=QString::null, bool manage=true);

        void showPage( const QCString& page );


    private:


        class ArchiveLimits  *m_archivelimits;
        class ArchiveTypes  *m_archivetypes;
        class SpecialFileTypes     *m_specialfiletypes;
	class AutoScanOptions     *m_autoscanoptions;
	class LogOptions     *m_logoptions;

        QValueList<QWidget*> m_pageList;
        QMap<QString, QString> m_pluginName;
        QMap<QString, QString> m_pluginKlamavName;
};


#endif // KLAMAVCONFIGDIALOG_H
